@@ -1,3 +1,5 @@
+use crate::pda::PDA;
+
 use anchor_lang::prelude::*;
 use anchor_lang::AccountDeserialize;
 use std::convert::TryFrom;
@@ -16,3 +18,9 @@ impl TryFrom<Vec<u8>> for Authority {
         Authority::try_deserialize(&mut data.as_slice())
     }
 }
+
+impl Authority {
+    pub fn find_pda() -> PDA {
+        Pubkey::find_program_address(&[SEED_AUTHORITY], &crate::ID)
+    }
+}
